@@ -15,11 +15,7 @@ use XML::Twig ;
 use File::Share ':all'; 
 use Carp qw (cluck croak carp) ;
 
-use Metabolomics::Banks qw( :all ) ;
-
-require Exporter;
-
-our @ISA = qw(Exporter);
+use base qw( Metabolomics::Banks ) ;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -82,8 +78,7 @@ our $VERSION = '0.1';
 sub new {
     ## Variables
     my $self={};
-    bless($self) ;
-    
+        
     $self = Metabolomics::Banks->new() ;
     
     $self->{_DATABASE_NAME_} = 'Blood Exposome' ;
@@ -92,7 +87,7 @@ sub new {
     $self->{_DATABASE_URL_} = 'database_url' ;
     $self->{_DATABASE_DOI_} = 'database_doi' ;
     ## _DATABASE_ENTRIES_
-    
+    bless($self) ;
     return $self ;
 }
 ### END of SUB
