@@ -14,13 +14,9 @@ use Carp qw (cluck croak carp) ;
 
 use FindBin;                 # locate this script
 use lib "$FindBin::Bin/../..";  # use the parent directory
-use Metabolomics::Banks qw( :all ) ;
+use base qw( Metabolomics::Banks ) ;
 use Metabolomics::Utils qw( :all ) ;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -82,8 +78,7 @@ our $VERSION = '0.1';
 sub new {
     ## Variables
     my $self={};
-    bless($self) ;
-    
+        
     $self = Metabolomics::Banks->new() ;
     
     $self->{_DATABASE_NAME_} = 'MaConDa' ;
@@ -93,7 +88,7 @@ sub new {
     $self->{_DATABASE_DOI_} = 'database_doi' ;
     $self->{_CONTAMINANTS_} = [] ;
     ## _DATABASE_ENTRIES_
-    
+    bless($self) ;
     return $self ;
 }
 ### END of SUB
